@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: edit.php,v 1.11 2008/01/08 18:28:43 gruberroland Exp $
+$Id: edit.php,v 1.12 2008/05/15 17:32:59 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Tilo Lutz
@@ -47,7 +47,7 @@ include_once('../../lib/modules.inc');
 startSecureSession();
 
 // Redirect to startpage if user is not loged in
-if (!isset($_SESSION['loggedIn'])) {
+if (!isset($_SESSION['loggedIn']) || ($_SESSION['loggedIn'] !== true)) {
 	metaRefresh("../login.php");
 	exit;
 	}
