@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: confmain.php,v 1.88 2007/10/26 17:51:56 gruberroland Exp $
+$Id: confmain.php,v 1.100 2008/04/24 18:45:14 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2007  Roland Gruber
@@ -45,11 +45,10 @@ setlanguage();
 
 // get password
 if (isset($_POST['passwd'])) $passwd = $_POST['passwd'];
-if (isset($_GET["modulesback"]) || isset($_GET["typesback"])) $passwd = $_SESSION['conf_config']->get_Passwd();
 
 // check if password was entered
 // if not: load login page
-if (! $passwd) {
+if (!isset($passwd) && !isset($_SESSION['conf_isAuthenticated'])) {
 	$_SESSION['conf_message'] = _("No password was entered!");
 	/** go back to login if password is empty */
 	require('conflogin.php');
@@ -63,7 +62,7 @@ $conf = &$_SESSION['conf_config'];
 
 // check if password is valid
 // if not: load login page
-if (!(($conf->get_Passwd()) == $passwd)) {
+if ((!isset($_SESSION['conf_isAuthenticated']) || !($_SESSION['conf_isAuthenticated'] === $conf->getName())) && !$conf->check_Passwd($passwd)) {
 	$sessionKeys = array_keys($_SESSION);
 	for ($i = 0; $i < sizeof($sessionKeys); $i++) {
 		if (substr($sessionKeys[$i], 0, 5) == "conf_") unset($_SESSION[$sessionKeys[$i]]);
@@ -73,25 +72,26 @@ if (!(($conf->get_Passwd()) == $passwd)) {
 	require('conflogin.php');
 	exit;
 }
+$_SESSION['conf_isAuthenticated'] = $conf->getName();
 
 // check if button was pressed and if we have to save the setting or go back to login
 if (isset($_POST['back']) || isset($_POST['submitconf']) || isset($_POST['editmodules']) || isset($_POST['edittypes'])){
 	// go to final page
-	if ($_POST['submitconf']){
+	if (isset($_POST['submitconf'])){
 		saveSettings();
 	}
 	// go to modules page
-	elseif ($_POST['editmodules']){
+	elseif (isset($_POST['editmodules'])){
 		metaRefresh("confmodules.php");
 		exit;
 	}
 	// go to types page
-	elseif ($_POST['edittypes']){
+	elseif (isset($_POST['edittypes'])){
 		metaRefresh("conftypes.php");
 		exit;
 	}
 	// back to login
-	else if ($_POST['back']){
+	else if (isset($_POST['back'])){
 		metaRefresh("../login.php");
 		exit;
 	}
@@ -120,10 +120,11 @@ echo $_SESSION['header'];
 
 echo ("<title>" . _("LDAP Account Manager Configuration") . "</title>\n");
 echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n");
+echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
 echo ("</head>\n");
 echo ("<body>\n");
 echo ("<p align=\"center\"><a href=\"http://lam.sourceforge.net\" target=\"new_window\">".
-	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p>\n<hr>\n<p></p>\n");
+	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p>\n<hr>\n<p>&nbsp;</p>\n");
 
 if (!$conf->isWritable()) {
 	StatusMessage('WARN', 'The config file is not writable.', 'Your changes cannot be saved until you make the file writable for the webserver user.');
@@ -141,7 +142,7 @@ if (isset($_SESSION['conf_errors'])) {
 // display formular
 echo ("<form action=\"confmain.php\" method=\"post\">\n");
 
-echo ("<fieldset><legend><b>" . _("Server settings") . "</b></legend>");
+echo ("<fieldset><legend><b>" . _("Server settings") . "</b></legend><br>\n");
 echo ("<table border=0>");
 // serverURL
 echo ("<tr><td align=\"right\"><b>" . _("Server address") . " *: </b></td>".
@@ -156,7 +157,7 @@ echo "</td></tr>\n";
 $tabindex++;
 
 // new line
-echo ("<tr><td colspan=3>&nbsp</td></tr>");
+echo ("<tr><td colspan=3>&nbsp;</td></tr>");
 
 // tree suffix
 echo ("<tr><td align=\"right\"><b>".
@@ -170,7 +171,7 @@ echo "</td></tr>\n";
 $tabindex++;
 
 // new line
-echo ("<tr><td colspan=3>&nbsp</td></tr>");
+echo ("<tr><td colspan=3>&nbsp;</td></tr>");
 
 // LDAP cache timeout
 echo ("<tr><td align=\"right\"><b>".
@@ -190,12 +191,48 @@ echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" .
 echo "</a>\n";
 echo "</td></tr>\n";
 
+// access level is only visible in Pro version
+if (isLAMProVersion()) {
+	// new line
+	echo ("<tr><td colspan=3>&nbsp;</td></tr>");
+	
+	// access level
+	echo ("<tr><td align=\"right\"><b>".
+		_("Access level") . ": </b></td>".
+		"<td><select tabindex=\"$tabindex\" name=\"accessLevel\">\n");
+	if ($conf->getAccessLevel() == LAMConfig::ACCESS_ALL) {
+		echo("<option selected value=" . LAMConfig::ACCESS_ALL . ">" . _('Write access') . "</option>\n");
+	}
+	else {
+		echo("<option value=" . LAMConfig::ACCESS_ALL . ">" . _('Write access') . "</option>\n");
+	}
+	if ($conf->getAccessLevel() == LAMConfig::ACCESS_PASSWORD_CHANGE) {
+		echo("<option selected value=" . LAMConfig::ACCESS_PASSWORD_CHANGE . ">" . _('Change passwords') . "</option>\n");
+	}
+	else {
+		echo("<option value=" . LAMConfig::ACCESS_PASSWORD_CHANGE . ">" . _('Change passwords') . "</option>\n");
+	}
+	if ($conf->getAccessLevel() == LAMConfig::ACCESS_READ_ONLY) {
+		echo("<option selected value=" . LAMConfig::ACCESS_READ_ONLY . ">" . _('Read only') . "</option>\n");
+	}
+	else {
+		echo("<option value=" . LAMConfig::ACCESS_READ_ONLY . ">" . _('Read only') . "</option>\n");
+	}
+	echo ("</select></td>\n");
+	$tabindex++;
+	echo "<td>";
+	echo "<a href=\"../help.php?HelpNumber=214\" target=\"lamhelp\">";
+	echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
+	echo "</a>\n";
+	echo "</td></tr>\n";
+}
+
 echo ("</table>");
 echo ("</fieldset>");
 
-echo ("<p></p>");
+echo ("<br>");
 
-echo ("<fieldset><legend><b>" . _("Account types and modules") . "</b></legend>");
+echo ("<fieldset><legend><b>" . _("Account types and modules") . "</b></legend><br>\n");
 
 // Account modules
 $types = $conf->get_ActiveTypes();
@@ -215,7 +252,7 @@ $tabindex++;
 
 echo ("</fieldset>");
 
-echo ("<p></p>");
+echo ("<br>");
 
 
 // module settings
@@ -239,7 +276,13 @@ $_SESSION['conf_types'] = array();
 for ($i = 0; $i < sizeof($modules); $i++) {
 	if (sizeof($options[$modules[$i]]) < 1) continue;
 	echo "<fieldset>\n";
-	echo "<legend><b>" . getModuleAlias($modules[$i], "none") . "</b></legend>\n";
+	$icon = '';
+	$module = new $modules[$i]('none');
+	$iconImage = $module->getIcon();
+	if ($iconImage != null) {
+		$icon = '<img align="middle" src="../../graphics/' . $iconImage . '" alt="' . $iconImage . '"> ';
+	}
+	echo "<legend>$icon<b>" . getModuleAlias($modules[$i], "none") . "</b></legend><br>\n";
 	$configTypes = parseHtml($modules[$i], $options[$modules[$i]], $old_options, true, $tabindex, $tabindexLink, 'config');
 	$_SESSION['conf_types'] = array_merge($configTypes, $_SESSION['conf_types']);
 	echo "</fieldset>\n";
@@ -247,32 +290,7 @@ for ($i = 0; $i < sizeof($modules); $i++) {
 }
 
 
-echo ("<fieldset><legend><b>" . _("List settings") . "</b></legend>\n");
-echo ("<table border=0>\n");
-
-// maximum list entries
-echo ("<tr><td align=\"right\"><b>".
-	_("Maximum list entries") . ": </b></td>".
-	"<td><select tabindex=\"$tabindex\" name=\"maxlistentries\">\n<option selected>".$conf->get_MaxListEntries()."</option>\n");
-if ($conf->get_MaxListEntries() != 10) echo("<option>10</option>\n");
-if ($conf->get_MaxListEntries() != 20) echo("<option>20</option>\n");
-if ($conf->get_MaxListEntries() != 30) echo("<option>30</option>\n");
-if ($conf->get_MaxListEntries() != 50) echo("<option>50</option>\n");
-if ($conf->get_MaxListEntries() != 75) echo("<option>75</option>\n");
-if ($conf->get_MaxListEntries() != 100) echo("<option>100</option>\n");
-echo ("</select></td>\n");
-$tabindex++;
-echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=208\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
-echo "</td></tr>\n";
-
-echo ("</table>\n");
-echo ("</fieldset>\n");
-echo ("<p></p>\n");
-
-echo ("<fieldset><legend><b>" . _("Language settings") . "</b></legend>\n");
+echo ("<fieldset><legend><b>" . _("Language settings") . "</b></legend><br>\n");
 echo ("<table border=0>\n");
 
 // language
@@ -316,10 +334,10 @@ echo "</td></tr>\n";
 echo ("</table>\n");
 echo ("</fieldset>\n");
 
-echo ("<p></p>\n");
+echo ("<br>\n");
 
 // script settings
-echo ("<fieldset><legend><b>" . _("Script settings") . "</b></legend>\n");
+echo ("<fieldset><legend><b>" . _("Script settings") . "</b></legend><br>\n");
 echo ("<table border=0>\n");
 
 echo ("<tr><td align=\"right\"><b>".
@@ -389,16 +407,16 @@ echo "</td></tr>\n";
 echo ("</table>\n");
 echo ("</fieldset>\n");
 
-echo ("<p></p>\n");
+echo ("<br>\n");
 
 // security setings
-echo ("<fieldset><legend><b>" . _("Security settings") . "</b></legend>\n");
+echo ("<fieldset><legend><b>" . _("Security settings") . "</b></legend><br>\n");
 echo ("<table border=0>\n");
 // admin list
 $adminText = implode("\n", explode(";", $conf->get_Adminstring()));
 echo ("<tr><td align=\"right\"><b>".
 	_("List of valid users") . " *: </b></td>".
-	"<td><textarea tabindex=\"$tabindex\" size=50 type=\"text\" name=\"admins\" cols=75 rows=5>" . $adminText . "</textarea></td>\n");
+	"<td><textarea tabindex=\"$tabindex\" name=\"admins\" cols=75 rows=5>" . $adminText . "</textarea></td>\n");
 echo "<td>";
 echo "<a href=\"../help.php?HelpNumber=207\" target=\"lamhelp\">";
 echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
@@ -425,7 +443,7 @@ echo ("<tr><td align=\"right\"><font color=\"red\"><b>".
 $tabindex++;
 echo ("</table>\n");
 echo ("</fieldset>\n");
-echo ("<p></p>\n");
+echo ("<p>&nbsp;</p>\n");
 
 
 // buttons
@@ -443,13 +461,9 @@ echo ("></pre></td></tr>\n");
 
 echo ("</table>\n");
 
-echo ("<p></p>");
+echo ("<p>&nbsp;</p>");
 
 echo ("<p>* = ". _("required") . "</p>");
-echo ("<p>** = ". _("required for Samba 3 accounts") . "</p>");
-
-// password for configuration
-echo ("<p><input type=\"hidden\" name=\"passwd\" value=\"" . $passwd . "\"></p>\n");
 
 echo ("</form>\n");
 echo ("</body>\n");
@@ -479,6 +493,9 @@ function saveSettings() {
 	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
 		$errors[] = array("ERROR", _("Cache timeout is invalid!"));
 	}
+	if (isLAMProVersion()) {
+		$conf->setAccessLevel($_POST['accessLevel']);
+	}
 	$adminText = $_POST['admins'];
 	$adminText = explode("\n", $adminText);
 	$adminTextNew = array();
@@ -492,9 +509,6 @@ function saveSettings() {
 	if (!$conf->set_Suffix("tree", $_POST['sufftree'])) {
 		$errors[] = array("ERROR", _("TreeSuffix is invalid!"));
 	}
-	if (!$conf->set_MaxListEntries($_POST['maxlistentries'])) {
-		$errors[] = array("ERROR", _("Max list entries is invalid!"));
-	}
 	if (!$conf->set_defaultLanguage($_POST['lang'])) {
 		$errors[] = array("ERROR", _("Language is not defined!"));
 	}
@@ -543,7 +557,7 @@ function saveSettings() {
 		}
 		// checkboxes
 		elseif ($_SESSION['conf_types'][$element] == "checkbox") {
-			if ($_POST[$element] == "on") $options[$element] = array('true');
+			if (isset($_POST[$element]) && ($_POST[$element] == "on")) $options[$element] = array('true');
 			else $options[$element] = array('false');
 		}
 		// dropdownbox
@@ -554,6 +568,10 @@ function saveSettings() {
 		elseif ($_SESSION['conf_types'][$element] == "multiselect") {
 			$options[$element] = $_POST[$element];  // value is already an array
 		}
+		// textarea
+		elseif ($_SESSION['conf_types'][$element] == "textarea") {
+			$options[$element] = explode("\r\n", $_POST[$element]);
+		}
 	}
 
 	// get list of scopes of modules
@@ -575,6 +593,7 @@ function saveSettings() {
 		echo $_SESSION['header'];
 		echo "<title>" . _("LDAP Account Manager Configuration") . "</title>\n";
 		echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
+		echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
 		echo "</head><body>\n";
 		echo ("<p align=\"center\"><a href=\"http://lam.sourceforge.net\" target=\"new_window\">".
 			"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p><hr><br><br>");
