@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: conftypes.php,v 1.9 2006/03/26 17:51:25 gruberroland Exp $
+$Id: conftypes.php,v 1.13 2008/04/24 18:45:15 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2004 - 2006  Roland Gruber
@@ -67,7 +67,7 @@ if (isset($_POST['postAvailable'])) {
 
 $errors = array();
 // user pressed submit/abort button
-if ($_POST['submit']) {
+if (isset($_POST['submit'])) {
 	// check settings
 	$allOK = true;
 	$postKeys = array_keys($_POST);
@@ -111,7 +111,7 @@ if ($_POST['submit']) {
 	}
 }
 // no changes
-elseif ($_POST['abort']) {
+elseif (isset($_POST['abort'])) {
 	$_SESSION['conf_accountTypes'] = $_SESSION['conf_accountTypesOld'];
 	metarefresh('confmain.php?typesback=true');
 	exit;
@@ -153,6 +153,7 @@ echo $_SESSION['header'];
 
 echo "<title>" . _("LDAP Account Manager Configuration") . "</title>\n";
 echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
+echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
 for ($i = 0; $i < sizeof($allTypes); $i++){
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $allTypes[$i] . ".css\">\n";
 }
@@ -172,8 +173,9 @@ if (sizeof($availableTypes) > 0) {
 	echo "<fieldset><legend><b>" . _("Available account types") . "</b></legend>\n";
 	echo "<table>\n";
 	for ($i = 0; $i < sizeof($availableTypes); $i++) {
+		$icon = '<img alt="' . $availableTypes[$i] . '" src="../../graphics/' . $availableTypes[$i] . '.png">&nbsp;';
 		echo "<tr>\n";
-			echo "<td><b>" . getTypeAlias($availableTypes[$i]) . ": </b></td>\n";
+			echo "<td>$icon<b>" . getTypeAlias($availableTypes[$i]) . ": </b></td>\n";
 			echo "<td>" . getTypeDescription($availableTypes[$i]) . "</td>\n";
 			echo "<td><input type=\"submit\" name=\"add_" . $availableTypes[$i] ."\" value=\"" . _("Add") . "\"></td>\n";
 		echo "</tr>\n";
@@ -189,7 +191,8 @@ if (sizeof($activeTypes) > 0) {
 	echo "<fieldset><legend><b>" . _("Active account types") . "</b></legend><br>\n";
 	for ($i = 0; $i < sizeof($activeTypes); $i++) {
 		echo "<fieldset class=\"" . $activeTypes[$i] . "edit\">\n";
-		echo "<legend>" . "<b>" . getTypeAlias($activeTypes[$i]) . ": </b>" . getTypeDescription($activeTypes[$i]) . "</legend>";
+		$icon = '<img alt="' . $activeTypes[$i] . '" src="../../graphics/' . $activeTypes[$i] . '.png">&nbsp;';
+		echo "<legend>" . $icon . "<b>" . getTypeAlias($activeTypes[$i]) . ": </b>" . getTypeDescription($activeTypes[$i]) . "</legend>";
 		echo "<br>\n";
 		echo "<table>\n";
 		// LDAP suffix
