@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: mainlogin.php,v 1.3 2006/09/24 14:19:50 gruberroland Exp $
+$Id: mainlogin.php,v 1.5 2008/01/01 13:06:50 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -47,7 +47,7 @@ if (isset($_SESSION["mainconf_password"])) unset($_SESSION["mainconf_password"])
 // check if user entered a password
 if (isset($_POST['passwd'])) {
 	$cfgMain = new LAMCfgMain();
-	if (isset($_POST['passwd']) && ($_POST['passwd'] == $cfgMain->password)) {
+	if (isset($_POST['passwd']) && ($cfgMain->checkPassword($_POST['passwd']))) {
 		$_SESSION["mainconf_password"] = $_POST['passwd'];
 		metaRefresh("mainmanage.php");
 		exit();
@@ -68,6 +68,7 @@ echo $_SESSION['header'];
 			?>
 		</title>
 		<link rel="stylesheet" type="text/css" href="../../style/layout.css">
+		<link rel="shortcut icon" type="image/x-icon" href="../../graphics/favicon.ico">
 	</head>
 	<body>
 		<?php
