@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: login.php,v 1.109 2008/03/23 10:57:33 gruberroland Exp $
+$Id: login.php,v 1.112 2008/07/30 20:34:19 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Michael Duergner
@@ -115,6 +115,11 @@ include_once("../lib/config.inc"); // Include config.inc which provides Config c
 session_save_path("../sess"); // Set session save path
 session_start(); // Start LDAP Account Manager session
 
+// save last selected login profile
+if(isset($_POST['profile'])) {
+	setcookie("lam_default_profile", $_POST['profile'], time() + 365*60*60*24);
+}
+
 /**
 * Displays the login window.
 *
@@ -229,6 +234,7 @@ function display_LoginPage($config_object) {
 			echo "<br>";
 		}
 		?>
+		<div style="position:relative; z-index:5;">
 		<table width="650" align="center" border="2" rules="none" bgcolor="white">
 			<tr>
 				<td style="border-style:none" width="70" rowspan="2">
@@ -364,6 +370,7 @@ function display_LoginPage($config_object) {
 				</td>
 			</tr>
 		</table>
+		</div>
 		<br><br>
 			<TABLE style="position:absolute; bottom:10px;" border="0" width="99%">
 				<TR><TD align="right"><HR>
@@ -455,11 +462,12 @@ elseif(!empty($_POST['profileChange'])) {
 	display_LoginPage($_SESSION['config']); // Load login page
 }
 // Load login page
-else
-{
-	$_SESSION['loggedIn'] = false;
+else {
 	$default_Config = new LAMCfgMain();
 	$default_Profile = $default_Config->default;
+	if(isset($_COOKIE["lam_default_profile"])) {
+		$default_Profile = $_COOKIE["lam_default_profile"];
+	}
 	$_SESSION["config"] = new LAMConfig($default_Profile); // Create new Config object
 	$_SESSION["cfgMain"] = $default_Config; // Create new CfgMain object
 
