@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: logout.php,v 1.17 2005/08/10 19:18:35 gruberroland Exp $
+$Id: logout.php,v 1.21 2006/04/23 16:33:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Roland Gruber
+  Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,14 +35,19 @@ if (function_exists('mcrypt_create_iv')) {
 	setcookie("IV", "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx", 0, "/");
 }
 
+/** security functions */
+include_once("../lib/security.inc");
 /** Used to display status messages */
 include_once("../lib/status.inc");
 /** LDAP settings are deleted at logout */
 include_once("../lib/ldap.inc");
 
 // start session
-session_save_path("../sess");
-@session_start();
+startSecureSession();
+
+// log message
+$ldapUser = $_SESSION['ldap']->decrypt_login();
+logNewMessage(LOG_NOTICE, 'User ' . $ldapUser[0] . ' logged off.');
 
 // close LDAP connection
 @$_SESSION["ldap"]->destroy();
@@ -64,7 +69,7 @@ unset($_SESSION);
 	<link rel="stylesheet" type="text/css" href="../style/layout.css">
 	</head>
 	<body>
-	<p align="center"><a href="http://lam.sf.net" target="new_window">
+	<p align="center"><a href="http://lam.sourceforge.net" target="new_window">
 		<img src="../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
 	</p>
 	<hr>
