@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: main.php,v 1.39 2008/03/23 10:57:33 gruberroland Exp $
+$Id: main.php,v 1.40 2008/09/04 17:43:31 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -49,7 +49,7 @@ $new_suffs = array();
 // get list of active types
 $types = $_SESSION['config']->get_ActiveTypes();
 for ($i = 0; $i < sizeof($types); $i++) {
-	$info = @ldap_search($_SESSION['ldap']->server(), $conf->get_Suffix($types[$i]), "(objectClass=*)", array('objectClass'));
+	$info = @ldap_search($_SESSION['ldap']->server(), escapeDN($conf->get_Suffix($types[$i])), "(objectClass=*)", array('objectClass'));
 	$res = @ldap_get_entries($_SESSION['ldap']->server(), $info);
 	if (!$res && !in_array($conf->get_Suffix($types[$i]), $new_suffs)) $new_suffs[] = $conf->get_Suffix($types[$i]);
 }
