@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: main_header.php,v 1.39 2006/10/18 16:08:58 gruberroland Exp $
+$Id: main_header.php,v 1.40 2007/04/21 11:04:50 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -66,7 +66,7 @@ $types = $_SESSION['config']->get_ActiveTypes();
 		<td align="center">
 			<a href="http://lam.sourceforge.net" target="new_window"><img src="../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
 		</td>
-	<td width="200" align="right" height=20><a href="./logout.php" target="_top"><img alt="logout" src="../graphics/go.png">&nbsp;<big><b><?php echo _("Logout") ?></b></big></a></td>
+	<td width="200" align="right" height=20><a href="./logout.php" target="_top"><img alt="logout" src="../graphics/exit.png">&nbsp;<big><b><?php echo _("Logout") ?></b></big></a></td>
 	</tr>
 </table>
 	<p align="center">
