@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: masscreate.php,v 1.77 2008/01/08 18:26:13 gruberroland Exp $
+$Id: masscreate.php,v 1.78 2008/05/15 17:32:22 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2004 - 2006  Roland Gruber
@@ -45,7 +45,7 @@ startSecureSession();
 if (!checkIfWriteAccessIsAllowed()) die();
 
 // Redirect to startpage if user is not loged in
-if (!isset($_SESSION['loggedIn'])) {
+if (!isset($_SESSION['loggedIn']) || ($_SESSION['loggedIn'] !== true)) {
 	metaRefresh("login.php");
 	exit;
 }
