@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profiledelete.php,v 1.20 2006/03/26 17:51:25 gruberroland Exp $
+$Id: profiledelete.php,v 1.21 2007/12/30 13:15:39 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -40,6 +40,9 @@ include_once("../../lib/config.inc");
 // start session
 startSecureSession();
 
+// die if no write access
+if (!checkIfWriteAccessIsAllowed()) die();
+
 setlanguage();
 
 // check if user is logged in, if not go to login
