@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profilemain.php,v 1.29 2007/12/31 13:13:37 gruberroland Exp $
+$Id: profilemain.php,v 1.31 2008/08/10 19:39:56 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -137,7 +137,7 @@ for ($i = 0; $i < sizeof($profileClasses); $i++) {
 	echo "<input type=\"radio\" name=\"profile\" value=\"edit" . $profileClasses[$i]['scope'] . "\">\n";
 	echo "</td>\n";
 	echo "<td>\n";
-	echo "<select name=\"e_" . $profileClasses[$i]['scope'] . "\" size=1>\n";
+	echo "<select class=\"" . $profileClasses[$i]['scope'] . "\" name=\"e_" . $profileClasses[$i]['scope'] . "\" size=1>\n";
 	echo $profileClasses[$i]['profiles'];
 	echo "</select>\n";
 	echo "</td>\n";
@@ -150,7 +150,7 @@ for ($i = 0; $i < sizeof($profileClasses); $i++) {
 	echo "<input type=\"radio\" name=\"profile\" value=\"del" . $profileClasses[$i]['scope'] . "\">\n";
 	echo "</td>\n";
 	echo "<td>\n";
-	echo "<select name=\"d_" . $profileClasses[$i]['scope'] . "\" size=1>\n";
+	echo "<select class=\"" . $profileClasses[$i]['scope'] . "\" name=\"d_" . $profileClasses[$i]['scope'] . "\" size=1>\n";
 	echo $profileClasses[$i]['profiles'];
 	echo "</select>\n";
 	echo "</td>\n";
