@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: lamdaemonTest.php,v 1.11 2008/01/27 16:12:06 gruberroland Exp $
+$Id: lamdaemonTest.php,v 1.12 2008/07/03 18:42:26 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2006 - 2007  Roland Gruber
@@ -269,7 +269,13 @@ function lamRunLamdaemonTestSuite($serverName, $serverTitle, $testQuota) {
 		echo "<tr class=\"userlist\">\n<td nowrap>" . _("SSH connection") . "&nbsp;&nbsp;</td>\n";
 		flush();
 		$sshOk = false;
-		$handle = @ssh2_connect($serverName);
+		$serverNameParts = explode(",", $serverName);
+		if (sizeof($serverNameParts) > 1) {
+			$handle = @ssh2_connect($serverNameParts[0], $serverNameParts[1]);
+		}
+		else {
+			$handle = @ssh2_connect($serverName);
+		}
 		if ($handle) {
 			if (@ssh2_auth_password($handle, $userName, $credentials[1])) {
 				$sshOk = true;
