@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: creation_template.php,v 1.2 2006/03/26 17:51:25 gruberroland Exp $
+$Id: creation_template.php,v 1.3 2007/07/08 10:49:06 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -71,7 +71,7 @@ if( $template == 'custom' ) {
 
 $template_id = $template;
 $template = isset( $templates[$template] ) ? $templates[$template_id] : null;
-$ds = $_SESSION['ldap']->server;
+$ds = $_SESSION['ldap']->server();
 
 echo $_SESSION['header'];
 
